==> activemq-optional-5.0.0-sources.jar: org/apache/activemq/transport/https/HttpsTransportFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.transport.https;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URI;

import org.apache.activemq.transport.Transport;
import org.apache.activemq.transport.TransportServer;
import org.apache.activemq.transport.http.HttpTransportFactory;
import org.apache.activemq.wireformat.WireFormat;

/**
 * Factory of HTTPS based transports
 * 
 * @version $Revision: 1.1 $
 */
public class HttpsTransportFactory extends HttpTransportFactory {
    
    public TransportServer doBind(String brokerId, URI location) throws IOException {
        return new HttpsTransportServer(location);
    }

    protected Transport createTransport(URI location, WireFormat wf) throws MalformedURLException {
        return new HttpsTransport(asTextWireFormat(wf), location);
    }

}

==> activemq-optional-5.1.0-sources.jar: org/apache/activemq/transport/https/HttpsTransportFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.transport.https;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URI;

import org.apache.activemq.transport.Transport;
import org.apache.activemq.transport.TransportServer;
import org.apache.activemq.transport.http.HttpTransportFactory;
import org.apache.activemq.wireformat.WireFormat;

/**
 * Factory of HTTPS based transports
 * 
 * @version $Revision: 1.1 $
 */
public class HttpsTransportFactory extends HttpTransportFactory {
    
    public TransportServer doBind(String brokerId, URI location) throws IOException {
        return new HttpsTransportServer(location);
    }

    protected Transport createTransport(URI location, WireFormat wf) throws MalformedURLException {
        return new HttpsClientTransport(asTextWireFormat(wf), location);
    }

}
